# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'AppsDashboardMetadataArgs',
    'AppsDashboardMetadataArgsDict',
    'AppsDashboardOptionsArgs',
    'AppsDashboardOptionsArgsDict',
    'AppsDashboardSpecArgs',
    'AppsDashboardSpecArgsDict',
    'AppsPlaylistV0Alpha1MetadataArgs',
    'AppsPlaylistV0Alpha1MetadataArgsDict',
    'AppsPlaylistV0Alpha1OptionsArgs',
    'AppsPlaylistV0Alpha1OptionsArgsDict',
    'AppsPlaylistV0Alpha1SpecArgs',
    'AppsPlaylistV0Alpha1SpecArgsDict',
    'AppsPlaylistV0Alpha1SpecItemArgs',
    'AppsPlaylistV0Alpha1SpecItemArgsDict',
]

MYPY = False

if not MYPY:
    class AppsDashboardMetadataArgsDict(TypedDict):
        uid: pulumi.Input[builtins.str]
        """
        The unique identifier of the resource.
        """
        folder_uid: NotRequired[pulumi.Input[builtins.str]]
        """
        The UID of the folder to save the resource in.
        """
        url: NotRequired[pulumi.Input[builtins.str]]
        """
        The full URL of the resource.
        """
        uuid: NotRequired[pulumi.Input[builtins.str]]
        """
        The globally unique identifier of a resource, used by the API for tracking.
        """
        version: NotRequired[pulumi.Input[builtins.str]]
        """
        The version of the resource.
        """
elif False:
    AppsDashboardMetadataArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class AppsDashboardMetadataArgs:
    def __init__(__self__, *,
                 uid: pulumi.Input[builtins.str],
                 folder_uid: Optional[pulumi.Input[builtins.str]] = None,
                 url: Optional[pulumi.Input[builtins.str]] = None,
                 uuid: Optional[pulumi.Input[builtins.str]] = None,
                 version: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] uid: The unique identifier of the resource.
        :param pulumi.Input[builtins.str] folder_uid: The UID of the folder to save the resource in.
        :param pulumi.Input[builtins.str] url: The full URL of the resource.
        :param pulumi.Input[builtins.str] uuid: The globally unique identifier of a resource, used by the API for tracking.
        :param pulumi.Input[builtins.str] version: The version of the resource.
        """
        pulumi.set(__self__, "uid", uid)
        if folder_uid is not None:
            pulumi.set(__self__, "folder_uid", folder_uid)
        if url is not None:
            pulumi.set(__self__, "url", url)
        if uuid is not None:
            pulumi.set(__self__, "uuid", uuid)
        if version is not None:
            pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter
    def uid(self) -> pulumi.Input[builtins.str]:
        """
        The unique identifier of the resource.
        """
        return pulumi.get(self, "uid")

    @uid.setter
    def uid(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "uid", value)

    @property
    @pulumi.getter(name="folderUid")
    def folder_uid(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The UID of the folder to save the resource in.
        """
        return pulumi.get(self, "folder_uid")

    @folder_uid.setter
    def folder_uid(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "folder_uid", value)

    @property
    @pulumi.getter
    def url(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The full URL of the resource.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "url", value)

    @property
    @pulumi.getter
    def uuid(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The globally unique identifier of a resource, used by the API for tracking.
        """
        return pulumi.get(self, "uuid")

    @uuid.setter
    def uuid(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "uuid", value)

    @property
    @pulumi.getter
    def version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The version of the resource.
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "version", value)


if not MYPY:
    class AppsDashboardOptionsArgsDict(TypedDict):
        overwrite: NotRequired[pulumi.Input[builtins.bool]]
        """
        Set to true if you want to overwrite existing resource with newer version, same resource title in folder or same resource uid.
        """
elif False:
    AppsDashboardOptionsArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class AppsDashboardOptionsArgs:
    def __init__(__self__, *,
                 overwrite: Optional[pulumi.Input[builtins.bool]] = None):
        """
        :param pulumi.Input[builtins.bool] overwrite: Set to true if you want to overwrite existing resource with newer version, same resource title in folder or same resource uid.
        """
        if overwrite is not None:
            pulumi.set(__self__, "overwrite", overwrite)

    @property
    @pulumi.getter
    def overwrite(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Set to true if you want to overwrite existing resource with newer version, same resource title in folder or same resource uid.
        """
        return pulumi.get(self, "overwrite")

    @overwrite.setter
    def overwrite(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "overwrite", value)


if not MYPY:
    class AppsDashboardSpecArgsDict(TypedDict):
        json: pulumi.Input[builtins.str]
        """
        The JSON representation of the dashboard spec.
        """
        tags: NotRequired[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]
        """
        The tags of the dashboard. If not set, the tags will be derived from the JSON spec.
        """
        title: NotRequired[pulumi.Input[builtins.str]]
        """
        The title of the dashboard. If not set, the title will be derived from the JSON spec.
        """
elif False:
    AppsDashboardSpecArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class AppsDashboardSpecArgs:
    def __init__(__self__, *,
                 json: pulumi.Input[builtins.str],
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 title: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] json: The JSON representation of the dashboard spec.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] tags: The tags of the dashboard. If not set, the tags will be derived from the JSON spec.
        :param pulumi.Input[builtins.str] title: The title of the dashboard. If not set, the title will be derived from the JSON spec.
        """
        pulumi.set(__self__, "json", json)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if title is not None:
            pulumi.set(__self__, "title", title)

    @property
    @pulumi.getter
    def json(self) -> pulumi.Input[builtins.str]:
        """
        The JSON representation of the dashboard spec.
        """
        return pulumi.get(self, "json")

    @json.setter
    def json(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "json", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        The tags of the dashboard. If not set, the tags will be derived from the JSON spec.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def title(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The title of the dashboard. If not set, the title will be derived from the JSON spec.
        """
        return pulumi.get(self, "title")

    @title.setter
    def title(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "title", value)


if not MYPY:
    class AppsPlaylistV0Alpha1MetadataArgsDict(TypedDict):
        uid: pulumi.Input[builtins.str]
        """
        The unique identifier of the resource.
        """
        folder_uid: NotRequired[pulumi.Input[builtins.str]]
        """
        The UID of the folder to save the resource in.
        """
        url: NotRequired[pulumi.Input[builtins.str]]
        """
        The full URL of the resource.
        """
        uuid: NotRequired[pulumi.Input[builtins.str]]
        """
        The globally unique identifier of a resource, used by the API for tracking.
        """
        version: NotRequired[pulumi.Input[builtins.str]]
        """
        The version of the resource.
        """
elif False:
    AppsPlaylistV0Alpha1MetadataArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class AppsPlaylistV0Alpha1MetadataArgs:
    def __init__(__self__, *,
                 uid: pulumi.Input[builtins.str],
                 folder_uid: Optional[pulumi.Input[builtins.str]] = None,
                 url: Optional[pulumi.Input[builtins.str]] = None,
                 uuid: Optional[pulumi.Input[builtins.str]] = None,
                 version: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] uid: The unique identifier of the resource.
        :param pulumi.Input[builtins.str] folder_uid: The UID of the folder to save the resource in.
        :param pulumi.Input[builtins.str] url: The full URL of the resource.
        :param pulumi.Input[builtins.str] uuid: The globally unique identifier of a resource, used by the API for tracking.
        :param pulumi.Input[builtins.str] version: The version of the resource.
        """
        pulumi.set(__self__, "uid", uid)
        if folder_uid is not None:
            pulumi.set(__self__, "folder_uid", folder_uid)
        if url is not None:
            pulumi.set(__self__, "url", url)
        if uuid is not None:
            pulumi.set(__self__, "uuid", uuid)
        if version is not None:
            pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter
    def uid(self) -> pulumi.Input[builtins.str]:
        """
        The unique identifier of the resource.
        """
        return pulumi.get(self, "uid")

    @uid.setter
    def uid(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "uid", value)

    @property
    @pulumi.getter(name="folderUid")
    def folder_uid(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The UID of the folder to save the resource in.
        """
        return pulumi.get(self, "folder_uid")

    @folder_uid.setter
    def folder_uid(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "folder_uid", value)

    @property
    @pulumi.getter
    def url(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The full URL of the resource.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "url", value)

    @property
    @pulumi.getter
    def uuid(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The globally unique identifier of a resource, used by the API for tracking.
        """
        return pulumi.get(self, "uuid")

    @uuid.setter
    def uuid(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "uuid", value)

    @property
    @pulumi.getter
    def version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The version of the resource.
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "version", value)


if not MYPY:
    class AppsPlaylistV0Alpha1OptionsArgsDict(TypedDict):
        overwrite: NotRequired[pulumi.Input[builtins.bool]]
        """
        Set to true if you want to overwrite existing resource with newer version, same resource title in folder or same resource uid.
        """
elif False:
    AppsPlaylistV0Alpha1OptionsArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class AppsPlaylistV0Alpha1OptionsArgs:
    def __init__(__self__, *,
                 overwrite: Optional[pulumi.Input[builtins.bool]] = None):
        """
        :param pulumi.Input[builtins.bool] overwrite: Set to true if you want to overwrite existing resource with newer version, same resource title in folder or same resource uid.
        """
        if overwrite is not None:
            pulumi.set(__self__, "overwrite", overwrite)

    @property
    @pulumi.getter
    def overwrite(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Set to true if you want to overwrite existing resource with newer version, same resource title in folder or same resource uid.
        """
        return pulumi.get(self, "overwrite")

    @overwrite.setter
    def overwrite(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "overwrite", value)


if not MYPY:
    class AppsPlaylistV0Alpha1SpecArgsDict(TypedDict):
        items: pulumi.Input[Sequence[pulumi.Input['AppsPlaylistV0Alpha1SpecItemArgsDict']]]
        """
        The items of the playlist.
        """
        title: pulumi.Input[builtins.str]
        """
        The title of the playlist.
        """
        interval: NotRequired[pulumi.Input[builtins.str]]
        """
        The interval of the playlist.
        """
elif False:
    AppsPlaylistV0Alpha1SpecArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class AppsPlaylistV0Alpha1SpecArgs:
    def __init__(__self__, *,
                 items: pulumi.Input[Sequence[pulumi.Input['AppsPlaylistV0Alpha1SpecItemArgs']]],
                 title: pulumi.Input[builtins.str],
                 interval: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[Sequence[pulumi.Input['AppsPlaylistV0Alpha1SpecItemArgs']]] items: The items of the playlist.
        :param pulumi.Input[builtins.str] title: The title of the playlist.
        :param pulumi.Input[builtins.str] interval: The interval of the playlist.
        """
        pulumi.set(__self__, "items", items)
        pulumi.set(__self__, "title", title)
        if interval is not None:
            pulumi.set(__self__, "interval", interval)

    @property
    @pulumi.getter
    def items(self) -> pulumi.Input[Sequence[pulumi.Input['AppsPlaylistV0Alpha1SpecItemArgs']]]:
        """
        The items of the playlist.
        """
        return pulumi.get(self, "items")

    @items.setter
    def items(self, value: pulumi.Input[Sequence[pulumi.Input['AppsPlaylistV0Alpha1SpecItemArgs']]]):
        pulumi.set(self, "items", value)

    @property
    @pulumi.getter
    def title(self) -> pulumi.Input[builtins.str]:
        """
        The title of the playlist.
        """
        return pulumi.get(self, "title")

    @title.setter
    def title(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "title", value)

    @property
    @pulumi.getter
    def interval(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The interval of the playlist.
        """
        return pulumi.get(self, "interval")

    @interval.setter
    def interval(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "interval", value)


if not MYPY:
    class AppsPlaylistV0Alpha1SpecItemArgsDict(TypedDict):
        type: pulumi.Input[builtins.str]
        value: pulumi.Input[builtins.str]
elif False:
    AppsPlaylistV0Alpha1SpecItemArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class AppsPlaylistV0Alpha1SpecItemArgs:
    def __init__(__self__, *,
                 type: pulumi.Input[builtins.str],
                 value: pulumi.Input[builtins.str]):
        pulumi.set(__self__, "type", type)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[builtins.str]:
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def value(self) -> pulumi.Input[builtins.str]:
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "value", value)





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetCollectorsResult',
    'AwaitableGetCollectorsResult',
    'get_collectors',
    'get_collectors_output',
]

@pulumi.output_type
class GetCollectorsResult:
    """
    A collection of values returned by getCollectors.
    """
    def __init__(__self__, collectors=None, id=None):
        if collectors and not isinstance(collectors, list):
            raise TypeError("Expected argument 'collectors' to be a list")
        pulumi.set(__self__, "collectors", collectors)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)

    @property
    @pulumi.getter
    def collectors(self) -> Sequence['outputs.GetCollectorsCollectorResult']:
        """
        List of collectors
        """
        return pulumi.get(self, "collectors")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")


class AwaitableGetCollectorsResult(GetCollectorsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCollectorsResult(
            collectors=self.collectors,
            id=self.id)


def get_collectors(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCollectorsResult:
    """
    Represents a list of Grafana Fleet Management collectors.

    * [Official documentation](https://grafana.com/docs/grafana-cloud/send-data/fleet-management/)
    * [API documentation](https://grafana.com/docs/grafana-cloud/send-data/fleet-management/api-reference/collector-api/)

    Required access policy scopes:

    * fleet-management:read

    ## Example Usage

    ```python
    import pulumi
    import pulumi_grafana as grafana

    test = grafana.fleetManagement.get_collectors()
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('grafana:fleetManagement/getCollectors:getCollectors', __args__, opts=opts, typ=GetCollectorsResult).value

    return AwaitableGetCollectorsResult(
        collectors=pulumi.get(__ret__, 'collectors'),
        id=pulumi.get(__ret__, 'id'))
def get_collectors_output(opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetCollectorsResult]:
    """
    Represents a list of Grafana Fleet Management collectors.

    * [Official documentation](https://grafana.com/docs/grafana-cloud/send-data/fleet-management/)
    * [API documentation](https://grafana.com/docs/grafana-cloud/send-data/fleet-management/api-reference/collector-api/)

    Required access policy scopes:

    * fleet-management:read

    ## Example Usage

    ```python
    import pulumi
    import pulumi_grafana as grafana

    test = grafana.fleetManagement.get_collectors()
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('grafana:fleetManagement/getCollectors:getCollectors', __args__, opts=opts, typ=GetCollectorsResult)
    return __ret__.apply(lambda __response__: GetCollectorsResult(
        collectors=pulumi.get(__response__, 'collectors'),
        id=pulumi.get(__response__, 'id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['DataSourceConfigLbacRulesArgs', 'DataSourceConfigLbacRules']

@pulumi.input_type
class DataSourceConfigLbacRulesArgs:
    def __init__(__self__, *,
                 datasource_uid: pulumi.Input[builtins.str],
                 rules: pulumi.Input[builtins.str]):
        """
        The set of arguments for constructing a DataSourceConfigLbacRules resource.
        :param pulumi.Input[builtins.str] datasource_uid: The UID of the datasource.
        :param pulumi.Input[builtins.str] rules: JSON-encoded LBAC rules for the data source. Map of team UIDs to lists of rule strings.
        """
        pulumi.set(__self__, "datasource_uid", datasource_uid)
        pulumi.set(__self__, "rules", rules)

    @property
    @pulumi.getter(name="datasourceUid")
    def datasource_uid(self) -> pulumi.Input[builtins.str]:
        """
        The UID of the datasource.
        """
        return pulumi.get(self, "datasource_uid")

    @datasource_uid.setter
    def datasource_uid(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "datasource_uid", value)

    @property
    @pulumi.getter
    def rules(self) -> pulumi.Input[builtins.str]:
        """
        JSON-encoded LBAC rules for the data source. Map of team UIDs to lists of rule strings.
        """
        return pulumi.get(self, "rules")

    @rules.setter
    def rules(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "rules", value)


@pulumi.input_type
class _DataSourceConfigLbacRulesState:
    def __init__(__self__, *,
                 datasource_uid: Optional[pulumi.Input[builtins.str]] = None,
                 rules: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering DataSourceConfigLbacRules resources.
        :param pulumi.Input[builtins.str] datasource_uid: The UID of the datasource.
        :param pulumi.Input[builtins.str] rules: JSON-encoded LBAC rules for the data source. Map of team UIDs to lists of rule strings.
        """
        if datasource_uid is not None:
            pulumi.set(__self__, "datasource_uid", datasource_uid)
        if rules is not None:
            pulumi.set(__self__, "rules", rules)

    @property
    @pulumi.getter(name="datasourceUid")
    def datasource_uid(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The UID of the datasource.
        """
        return pulumi.get(self, "datasource_uid")

    @datasource_uid.setter
    def datasource_uid(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "datasource_uid", value)

    @property
    @pulumi.getter
    def rules(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        JSON-encoded LBAC rules for the data source. Map of team UIDs to lists of rule strings.
        """
        return pulumi.get(self, "rules")

    @rules.setter
    def rules(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rules", value)


@pulumi.type_token("grafana:enterprise/dataSourceConfigLbacRules:DataSourceConfigLbacRules")
class DataSourceConfigLbacRules(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 datasource_uid: Optional[pulumi.Input[builtins.str]] = None,
                 rules: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Manages LBAC rules for a data source.

        !> Warning: The resource is experimental and will be subject to change. This resource manages the entire LBAC rules tree, and will overwrite any existing rules.

        * [Official documentation](https://grafana.com/docs/grafana/latest/administration/data-source-management/teamlbac/)
        * [HTTP API](https://grafana.com/docs/grafana/latest/developers/http_api/datasource_lbac_rules/)

        This resource requires Grafana >=11.5.0.

        ## Example Usage

        ```python
        import pulumi
        import json
        import pulumiverse_grafana as grafana

        team = grafana.oss.Team("team", name="Team Name")
        test = grafana.oss.DataSource("test",
            type="loki",
            name="loki-from-terraform",
            url="https://mylokiurl.net",
            basic_auth_enabled=True,
            basic_auth_username="username",
            json_data_encoded=json.dumps({
                "authType": "default",
                "basicAuthPassword": "password",
            }))
        test_rule = grafana.enterprise.DataSourceConfigLbacRules("test_rule",
            datasource_uid=test.uid,
            rules=pulumi.Output.json_dumps(team.team_uid.apply(lambda team_uid: {
                team_uid: [
                    "{ cluster = \\"dev-us-central-0\\", namespace = \\"hosted-grafana\\" }",
                    "{ foo = \\"qux\\" }",
                ],
            })),
            opts = pulumi.ResourceOptions(depends_on=[
                    team,
                    test,
                ]))
        ```

        ## Import

        ```sh
        $ pulumi import grafana:enterprise/dataSourceConfigLbacRules:DataSourceConfigLbacRules name "{{ datasource_uid }}"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] datasource_uid: The UID of the datasource.
        :param pulumi.Input[builtins.str] rules: JSON-encoded LBAC rules for the data source. Map of team UIDs to lists of rule strings.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DataSourceConfigLbacRulesArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages LBAC rules for a data source.

        !> Warning: The resource is experimental and will be subject to change. This resource manages the entire LBAC rules tree, and will overwrite any existing rules.

        * [Official documentation](https://grafana.com/docs/grafana/latest/administration/data-source-management/teamlbac/)
        * [HTTP API](https://grafana.com/docs/grafana/latest/developers/http_api/datasource_lbac_rules/)

        This resource requires Grafana >=11.5.0.

        ## Example Usage

        ```python
        import pulumi
        import json
        import pulumiverse_grafana as grafana

        team = grafana.oss.Team("team", name="Team Name")
        test = grafana.oss.DataSource("test",
            type="loki",
            name="loki-from-terraform",
            url="https://mylokiurl.net",
            basic_auth_enabled=True,
            basic_auth_username="username",
            json_data_encoded=json.dumps({
                "authType": "default",
                "basicAuthPassword": "password",
            }))
        test_rule = grafana.enterprise.DataSourceConfigLbacRules("test_rule",
            datasource_uid=test.uid,
            rules=pulumi.Output.json_dumps(team.team_uid.apply(lambda team_uid: {
                team_uid: [
                    "{ cluster = \\"dev-us-central-0\\", namespace = \\"hosted-grafana\\" }",
                    "{ foo = \\"qux\\" }",
                ],
            })),
            opts = pulumi.ResourceOptions(depends_on=[
                    team,
                    test,
                ]))
        ```

        ## Import

        ```sh
        $ pulumi import grafana:enterprise/dataSourceConfigLbacRules:DataSourceConfigLbacRules name "{{ datasource_uid }}"
        ```

        :param str resource_name: The name of the resource.
        :param DataSourceConfigLbacRulesArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DataSourceConfigLbacRulesArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 datasource_uid: Optional[pulumi.Input[builtins.str]] = None,
                 rules: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DataSourceConfigLbacRulesArgs.__new__(DataSourceConfigLbacRulesArgs)

            if datasource_uid is None and not opts.urn:
                raise TypeError("Missing required property 'datasource_uid'")
            __props__.__dict__["datasource_uid"] = datasource_uid
            if rules is None and not opts.urn:
                raise TypeError("Missing required property 'rules'")
            __props__.__dict__["rules"] = rules
        super(DataSourceConfigLbacRules, __self__).__init__(
            'grafana:enterprise/dataSourceConfigLbacRules:DataSourceConfigLbacRules',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            datasource_uid: Optional[pulumi.Input[builtins.str]] = None,
            rules: Optional[pulumi.Input[builtins.str]] = None) -> 'DataSourceConfigLbacRules':
        """
        Get an existing DataSourceConfigLbacRules resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] datasource_uid: The UID of the datasource.
        :param pulumi.Input[builtins.str] rules: JSON-encoded LBAC rules for the data source. Map of team UIDs to lists of rule strings.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DataSourceConfigLbacRulesState.__new__(_DataSourceConfigLbacRulesState)

        __props__.__dict__["datasource_uid"] = datasource_uid
        __props__.__dict__["rules"] = rules
        return DataSourceConfigLbacRules(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="datasourceUid")
    def datasource_uid(self) -> pulumi.Output[builtins.str]:
        """
        The UID of the datasource.
        """
        return pulumi.get(self, "datasource_uid")

    @property
    @pulumi.getter
    def rules(self) -> pulumi.Output[builtins.str]:
        """
        JSON-encoded LBAC rules for the data source. Map of team UIDs to lists of rule strings.
        """
        return pulumi.get(self, "rules")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetCollectorResult',
    'AwaitableGetCollectorResult',
    'get_collector',
    'get_collector_output',
]

@pulumi.output_type
class GetCollectorResult:
    """
    A collection of values returned by getCollector.
    """
    def __init__(__self__, enabled=None, id=None, local_attributes=None, remote_attributes=None):
        if enabled and not isinstance(enabled, bool):
            raise TypeError("Expected argument 'enabled' to be a bool")
        pulumi.set(__self__, "enabled", enabled)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if local_attributes and not isinstance(local_attributes, dict):
            raise TypeError("Expected argument 'local_attributes' to be a dict")
        pulumi.set(__self__, "local_attributes", local_attributes)
        if remote_attributes and not isinstance(remote_attributes, dict):
            raise TypeError("Expected argument 'remote_attributes' to be a dict")
        pulumi.set(__self__, "remote_attributes", remote_attributes)

    @property
    @pulumi.getter
    def enabled(self) -> builtins.bool:
        """
        Whether remote configuration for the collector is enabled or not. If the collector is disabled, it will receive empty configurations from the Fleet Management service
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        ID of the collector
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="localAttributes")
    def local_attributes(self) -> Mapping[str, builtins.str]:
        """
        Local attributes for the collector
        """
        return pulumi.get(self, "local_attributes")

    @property
    @pulumi.getter(name="remoteAttributes")
    def remote_attributes(self) -> Mapping[str, builtins.str]:
        """
        Remote attributes for the collector
        """
        return pulumi.get(self, "remote_attributes")


class AwaitableGetCollectorResult(GetCollectorResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCollectorResult(
            enabled=self.enabled,
            id=self.id,
            local_attributes=self.local_attributes,
            remote_attributes=self.remote_attributes)


def get_collector(id: Optional[builtins.str] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCollectorResult:
    """
    Represents a Grafana Fleet Management collector.

    * [Official documentation](https://grafana.com/docs/grafana-cloud/send-data/fleet-management/)
    * [API documentation](https://grafana.com/docs/grafana-cloud/send-data/fleet-management/api-reference/collector-api/)

    Required access policy scopes:

    * fleet-management:read

    ## Example Usage

    ```python
    import pulumi
    import pulumi_grafana as grafana

    test = grafana.fleetManagement.get_collector(id="my_collector")
    ```


    :param builtins.str id: ID of the collector
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('grafana:fleetManagement/getCollector:getCollector', __args__, opts=opts, typ=GetCollectorResult).value

    return AwaitableGetCollectorResult(
        enabled=pulumi.get(__ret__, 'enabled'),
        id=pulumi.get(__ret__, 'id'),
        local_attributes=pulumi.get(__ret__, 'local_attributes'),
        remote_attributes=pulumi.get(__ret__, 'remote_attributes'))
def get_collector_output(id: Optional[pulumi.Input[builtins.str]] = None,
                         opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetCollectorResult]:
    """
    Represents a Grafana Fleet Management collector.

    * [Official documentation](https://grafana.com/docs/grafana-cloud/send-data/fleet-management/)
    * [API documentation](https://grafana.com/docs/grafana-cloud/send-data/fleet-management/api-reference/collector-api/)

    Required access policy scopes:

    * fleet-management:read

    ## Example Usage

    ```python
    import pulumi
    import pulumi_grafana as grafana

    test = grafana.fleetManagement.get_collector(id="my_collector")
    ```


    :param builtins.str id: ID of the collector
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('grafana:fleetManagement/getCollector:getCollector', __args__, opts=opts, typ=GetCollectorResult)
    return __ret__.apply(lambda __response__: GetCollectorResult(
        enabled=pulumi.get(__response__, 'enabled'),
        id=pulumi.get(__response__, 'id'),
        local_attributes=pulumi.get(__response__, 'local_attributes'),
        remote_attributes=pulumi.get(__response__, 'remote_attributes')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ContactPointArgs', 'ContactPoint']

@pulumi.input_type
class ContactPointArgs:
    def __init__(__self__, *,
                 alertmanagers: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointAlertmanagerArgs']]]] = None,
                 dingdings: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointDingdingArgs']]]] = None,
                 disable_provenance: Optional[pulumi.Input[builtins.bool]] = None,
                 discords: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointDiscordArgs']]]] = None,
                 emails: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointEmailArgs']]]] = None,
                 googlechats: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointGooglechatArgs']]]] = None,
                 kafkas: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointKafkaArgs']]]] = None,
                 lines: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointLineArgs']]]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 oncalls: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointOncallArgs']]]] = None,
                 opsgenies: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointOpsgenyArgs']]]] = None,
                 org_id: Optional[pulumi.Input[builtins.str]] = None,
                 pagerduties: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointPagerdutyArgs']]]] = None,
                 pushovers: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointPushoverArgs']]]] = None,
                 sensugos: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointSensugoArgs']]]] = None,
                 slacks: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointSlackArgs']]]] = None,
                 sns: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointSnArgs']]]] = None,
                 teams: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointTeamArgs']]]] = None,
                 telegrams: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointTelegramArgs']]]] = None,
                 threemas: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointThreemaArgs']]]] = None,
                 victorops: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointVictoropArgs']]]] = None,
                 webexes: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointWebexArgs']]]] = None,
                 webhooks: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointWebhookArgs']]]] = None,
                 wecoms: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointWecomArgs']]]] = None):
        """
        The set of arguments for constructing a ContactPoint resource.
        :param pulumi.Input[Sequence[pulumi.Input['ContactPointAlertmanagerArgs']]] alertmanagers: A contact point that sends notifications to other Alertmanager instances.
        :param pulumi.Input[Sequence[pulumi.Input['ContactPointDingdingArgs']]] dingdings: A contact point that sends notifications to DingDing.
        :param pulumi.Input[Sequence[pulumi.Input['ContactPointDiscordArgs']]] discords: A contact point that sends notifications as Discord messages
        :param pulumi.Input[Sequence[pulumi.Input['ContactPointEmailArgs']]] emails: A contact point that sends notifications to an email address.
        :param pulumi.Input[Sequence[pulumi.Input['ContactPointGooglechatArgs']]] googlechats: A contact point that sends notifications to Google Chat.
        :param pulumi.Input[Sequence[pulumi.Input['ContactPointKafkaArgs']]] kafkas: A contact point that publishes notifications to Apache Kafka topics.
        :param pulumi.Input[Sequence[pulumi.Input['ContactPointLineArgs']]] lines: A contact point that sends notifications to LINE.me.
        :param pulumi.Input[builtins.str] name: The name of the contact point.
        :param pulumi.Input[Sequence[pulumi.Input['ContactPointOncallArgs']]] oncalls: A contact point that sends notifications to Grafana On-Call.
        :param pulumi.Input[Sequence[pulumi.Input['ContactPointOpsgenyArgs']]] opsgenies: A contact point that sends notifications to OpsGenie.
        :param pulumi.Input[builtins.str] org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
        :param pulumi.Input[Sequence[pulumi.Input['ContactPointPagerdutyArgs']]] pagerduties: A contact point that sends notifications to PagerDuty.
        :param pulumi.Input[Sequence[pulumi.Input['ContactPointPushoverArgs']]] pushovers: A contact point that sends notifications to Pushover.
        :param pulumi.Input[Sequence[pulumi.Input['ContactPointSensugoArgs']]] sensugos: A contact point that sends notifications to SensuGo.
        :param pulumi.Input[Sequence[pulumi.Input['ContactPointSlackArgs']]] slacks: A contact point that sends notifications to Slack.
        :param pulumi.Input[Sequence[pulumi.Input['ContactPointSnArgs']]] sns: A contact point that sends notifications to Amazon SNS. Requires Amazon Managed Grafana.
        :param pulumi.Input[Sequence[pulumi.Input['ContactPointTeamArgs']]] teams: A contact point that sends notifications to Microsoft Teams.
        :param pulumi.Input[Sequence[pulumi.Input['ContactPointTelegramArgs']]] telegrams: A contact point that sends notifications to Telegram.
        :param pulumi.Input[Sequence[pulumi.Input['ContactPointThreemaArgs']]] threemas: A contact point that sends notifications to Threema.
        :param pulumi.Input[Sequence[pulumi.Input['ContactPointVictoropArgs']]] victorops: A contact point that sends notifications to VictorOps (now known as Splunk OnCall).
        :param pulumi.Input[Sequence[pulumi.Input['ContactPointWebexArgs']]] webexes: A contact point that sends notifications to Cisco Webex.
        :param pulumi.Input[Sequence[pulumi.Input['ContactPointWebhookArgs']]] webhooks: A contact point that sends notifications to an arbitrary webhook, using the Prometheus webhook format defined here: https://prometheus.io/docs/alerting/latest/configuration/#webhook_config
        :param pulumi.Input[Sequence[pulumi.Input['ContactPointWecomArgs']]] wecoms: A contact point that sends notifications to WeCom.
        """
        if alertmanagers is not None:
            pulumi.set(__self__, "alertmanagers", alertmanagers)
        if dingdings is not None:
            pulumi.set(__self__, "dingdings", dingdings)
        if disable_provenance is not None:
            pulumi.set(__self__, "disable_provenance", disable_provenance)
        if discords is not None:
            pulumi.set(__self__, "discords", discords)
        if emails is not None:
            pulumi.set(__self__, "emails", emails)
        if googlechats is not None:
            pulumi.set(__self__, "googlechats", googlechats)
        if kafkas is not None:
            pulumi.set(__self__, "kafkas", kafkas)
        if lines is not None:
            pulumi.set(__self__, "lines", lines)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if oncalls is not None:
            pulumi.set(__self__, "oncalls", oncalls)
        if opsgenies is not None:
            pulumi.set(__self__, "opsgenies", opsgenies)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if pagerduties is not None:
            pulumi.set(__self__, "pagerduties", pagerduties)
        if pushovers is not None:
            pulumi.set(__self__, "pushovers", pushovers)
        if sensugos is not None:
            pulumi.set(__self__, "sensugos", sensugos)
        if slacks is not None:
            pulumi.set(__self__, "slacks", slacks)
        if sns is not None:
            pulumi.set(__self__, "sns", sns)
        if teams is not None:
            pulumi.set(__self__, "teams", teams)
        if telegrams is not None:
            pulumi.set(__self__, "telegrams", telegrams)
        if threemas is not None:
            pulumi.set(__self__, "threemas", threemas)
        if victorops is not None:
            pulumi.set(__self__, "victorops", victorops)
        if webexes is not None:
            pulumi.set(__self__, "webexes", webexes)
        if webhooks is not None:
            pulumi.set(__self__, "webhooks", webhooks)
        if wecoms is not None:
            pulumi.set(__self__, "wecoms", wecoms)

    @property
    @pulumi.getter
    def alertmanagers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointAlertmanagerArgs']]]]:
        """
        A contact point that sends notifications to other Alertmanager instances.
        """
        return pulumi.get(self, "alertmanagers")

    @alertmanagers.setter
    def alertmanagers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointAlertmanagerArgs']]]]):
        pulumi.set(self, "alertmanagers", value)

    @property
    @pulumi.getter
    def dingdings(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointDingdingArgs']]]]:
        """
        A contact point that sends notifications to DingDing.
        """
        return pulumi.get(self, "dingdings")

    @dingdings.setter
    def dingdings(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointDingdingArgs']]]]):
        pulumi.set(self, "dingdings", value)

    @property
    @pulumi.getter(name="disableProvenance")
    def disable_provenance(self) -> Optional[pulumi.Input[builtins.bool]]:
        return pulumi.get(self, "disable_provenance")

    @disable_provenance.setter
    def disable_provenance(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "disable_provenance", value)

    @property
    @pulumi.getter
    def discords(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointDiscordArgs']]]]:
        """
        A contact point that sends notifications as Discord messages
        """
        return pulumi.get(self, "discords")

    @discords.setter
    def discords(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointDiscordArgs']]]]):
        pulumi.set(self, "discords", value)

    @property
    @pulumi.getter
    def emails(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointEmailArgs']]]]:
        """
        A contact point that sends notifications to an email address.
        """
        return pulumi.get(self, "emails")

    @emails.setter
    def emails(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointEmailArgs']]]]):
        pulumi.set(self, "emails", value)

    @property
    @pulumi.getter
    def googlechats(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointGooglechatArgs']]]]:
        """
        A contact point that sends notifications to Google Chat.
        """
        return pulumi.get(self, "googlechats")

    @googlechats.setter
    def googlechats(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointGooglechatArgs']]]]):
        pulumi.set(self, "googlechats", value)

    @property
    @pulumi.getter
    def kafkas(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointKafkaArgs']]]]:
        """
        A contact point that publishes notifications to Apache Kafka topics.
        """
        return pulumi.get(self, "kafkas")

    @kafkas.setter
    def kafkas(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointKafkaArgs']]]]):
        pulumi.set(self, "kafkas", value)

    @property
    @pulumi.getter
    def lines(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointLineArgs']]]]:
        """
        A contact point that sends notifications to LINE.me.
        """
        return pulumi.get(self, "lines")

    @lines.setter
    def lines(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointLineArgs']]]]):
        pulumi.set(self, "lines", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the contact point.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def oncalls(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointOncallArgs']]]]:
        """
        A contact point that sends notifications to Grafana On-Call.
        """
        return pulumi.get(self, "oncalls")

    @oncalls.setter
    def oncalls(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointOncallArgs']]]]):
        pulumi.set(self, "oncalls", value)

    @property
    @pulumi.getter
    def opsgenies(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointOpsgenyArgs']]]]:
        """
        A contact point that sends notifications to OpsGenie.
        """
        return pulumi.get(self, "opsgenies")

    @opsgenies.setter
    def opsgenies(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointOpsgenyArgs']]]]):
        pulumi.set(self, "opsgenies", value)

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The Organization ID. If not set, the Org ID defined in the provider block will be used.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "org_id", value)

    @property
    @pulumi.getter
    def pagerduties(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointPagerdutyArgs']]]]:
        """
        A contact point that sends notifications to PagerDuty.
        """
        return pulumi.get(self, "pagerduties")

    @pagerduties.setter
    def pagerduties(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointPagerdutyArgs']]]]):
        pulumi.set(self, "pagerduties", value)

    @property
    @pulumi.getter
    def pushovers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointPushoverArgs']]]]:
        """
        A contact point that sends notifications to Pushover.
        """
        return pulumi.get(self, "pushovers")

    @pushovers.setter
    def pushovers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointPushoverArgs']]]]):
        pulumi.set(self, "pushovers", value)

    @property
    @pulumi.getter
    def sensugos(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointSensugoArgs']]]]:
        """
        A contact point that sends notifications to SensuGo.
        """
        return pulumi.get(self, "sensugos")

    @sensugos.setter
    def sensugos(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointSensugoArgs']]]]):
        pulumi.set(self, "sensugos", value)

    @property
    @pulumi.getter
    def slacks(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointSlackArgs']]]]:
        """
        A contact point that sends notifications to Slack.
        """
        return pulumi.get(self, "slacks")

    @slacks.setter
    def slacks(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointSlackArgs']]]]):
        pulumi.set(self, "slacks", value)

    @property
    @pulumi.getter
    def sns(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointSnArgs']]]]:
        """
        A contact point that sends notifications to Amazon SNS. Requires Amazon Managed Grafana.
        """
        return pulumi.get(self, "sns")

    @sns.setter
    def sns(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointSnArgs']]]]):
        pulumi.set(self, "sns", value)

    @property
    @pulumi.getter
    def teams(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointTeamArgs']]]]:
        """
        A contact point that sends notifications to Microsoft Teams.
        """
        return pulumi.get(self, "teams")

    @teams.setter
    def teams(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointTeamArgs']]]]):
        pulumi.set(self, "teams", value)

    @property
    @pulumi.getter
    def telegrams(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointTelegramArgs']]]]:
        """
        A contact point that sends notifications to Telegram.
        """
        return pulumi.get(self, "telegrams")

    @telegrams.setter
    def telegrams(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointTelegramArgs']]]]):
        pulumi.set(self, "telegrams", value)

    @property
    @pulumi.getter
    def threemas(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointThreemaArgs']]]]:
        """
        A contact point that sends notifications to Threema.
        """
        return pulumi.get(self, "threemas")

    @threemas.setter
    def threemas(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointThreemaArgs']]]]):
        pulumi.set(self, "threemas", value)

    @property
    @pulumi.getter
    def victorops(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointVictoropArgs']]]]:
        """
        A contact point that sends notifications to VictorOps (now known as Splunk OnCall).
        """
        return pulumi.get(self, "victorops")

    @victorops.setter
    def victorops(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointVictoropArgs']]]]):
        pulumi.set(self, "victorops", value)

    @property
    @pulumi.getter
    def webexes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointWebexArgs']]]]:
        """
        A contact point that sends notifications to Cisco Webex.
        """
        return pulumi.get(self, "webexes")

    @webexes.setter
    def webexes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointWebexArgs']]]]):
        pulumi.set(self, "webexes", value)

    @property
    @pulumi.getter
    def webhooks(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointWebhookArgs']]]]:
        """
        A contact point that sends notifications to an arbitrary webhook, using the Prometheus webhook format defined here: https://prometheus.io/docs/alerting/latest/configuration/#webhook_config
        """
        return pulumi.get(self, "webhooks")

    @webhooks.setter
    def webhooks(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointWebhookArgs']]]]):
        pulumi.set(self, "webhooks", value)

    @property
    @pulumi.getter
    def wecoms(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointWecomArgs']]]]:
        """
        A contact point that sends notifications to WeCom.
        """
        return pulumi.get(self, "wecoms")

    @wecoms.setter
    def wecoms(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointWecomArgs']]]]):
        pulumi.set(self, "wecoms", value)


@pulumi.input_type
class _ContactPointState:
    def __init__(__self__, *,
                 alertmanagers: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointAlertmanagerArgs']]]] = None,
                 dingdings: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointDingdingArgs']]]] = None,
                 disable_provenance: Optional[pulumi.Input[builtins.bool]] = None,
                 discords: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointDiscordArgs']]]] = None,
                 emails: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointEmailArgs']]]] = None,
                 googlechats: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointGooglechatArgs']]]] = None,
                 kafkas: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointKafkaArgs']]]] = None,
                 lines: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointLineArgs']]]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 oncalls: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointOncallArgs']]]] = None,
                 opsgenies: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointOpsgenyArgs']]]] = None,
                 org_id: Optional[pulumi.Input[builtins.str]] = None,
                 pagerduties: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointPagerdutyArgs']]]] = None,
                 pushovers: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointPushoverArgs']]]] = None,
                 sensugos: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointSensugoArgs']]]] = None,
                 slacks: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointSlackArgs']]]] = None,
                 sns: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointSnArgs']]]] = None,
                 teams: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointTeamArgs']]]] = None,
                 telegrams: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointTelegramArgs']]]] = None,
                 threemas: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointThreemaArgs']]]] = None,
                 victorops: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointVictoropArgs']]]] = None,
                 webexes: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointWebexArgs']]]] = None,
                 webhooks: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointWebhookArgs']]]] = None,
                 wecoms: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointWecomArgs']]]] = None):
        """
        Input properties used for looking up and filtering ContactPoint resources.
        :param pulumi.Input[Sequence[pulumi.Input['ContactPointAlertmanagerArgs']]] alertmanagers: A contact point that sends notifications to other Alertmanager instances.
        :param pulumi.Input[Sequence[pulumi.Input['ContactPointDingdingArgs']]] dingdings: A contact point that sends notifications to DingDing.
        :param pulumi.Input[Sequence[pulumi.Input['ContactPointDiscordArgs']]] discords: A contact point that sends notifications as Discord messages
        :param pulumi.Input[Sequence[pulumi.Input['ContactPointEmailArgs']]] emails: A contact point that sends notifications to an email address.
        :param pulumi.Input[Sequence[pulumi.Input['ContactPointGooglechatArgs']]] googlechats: A contact point that sends notifications to Google Chat.
        :param pulumi.Input[Sequence[pulumi.Input['ContactPointKafkaArgs']]] kafkas: A contact point that publishes notifications to Apache Kafka topics.
        :param pulumi.Input[Sequence[pulumi.Input['ContactPointLineArgs']]] lines: A contact point that sends notifications to LINE.me.
        :param pulumi.Input[builtins.str] name: The name of the contact point.
        :param pulumi.Input[Sequence[pulumi.Input['ContactPointOncallArgs']]] oncalls: A contact point that sends notifications to Grafana On-Call.
        :param pulumi.Input[Sequence[pulumi.Input['ContactPointOpsgenyArgs']]] opsgenies: A contact point that sends notifications to OpsGenie.
        :param pulumi.Input[builtins.str] org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
        :param pulumi.Input[Sequence[pulumi.Input['ContactPointPagerdutyArgs']]] pagerduties: A contact point that sends notifications to PagerDuty.
        :param pulumi.Input[Sequence[pulumi.Input['ContactPointPushoverArgs']]] pushovers: A contact point that sends notifications to Pushover.
        :param pulumi.Input[Sequence[pulumi.Input['ContactPointSensugoArgs']]] sensugos: A contact point that sends notifications to SensuGo.
        :param pulumi.Input[Sequence[pulumi.Input['ContactPointSlackArgs']]] slacks: A contact point that sends notifications to Slack.
        :param pulumi.Input[Sequence[pulumi.Input['ContactPointSnArgs']]] sns: A contact point that sends notifications to Amazon SNS. Requires Amazon Managed Grafana.
        :param pulumi.Input[Sequence[pulumi.Input['ContactPointTeamArgs']]] teams: A contact point that sends notifications to Microsoft Teams.
        :param pulumi.Input[Sequence[pulumi.Input['ContactPointTelegramArgs']]] telegrams: A contact point that sends notifications to Telegram.
        :param pulumi.Input[Sequence[pulumi.Input['ContactPointThreemaArgs']]] threemas: A contact point that sends notifications to Threema.
        :param pulumi.Input[Sequence[pulumi.Input['ContactPointVictoropArgs']]] victorops: A contact point that sends notifications to VictorOps (now known as Splunk OnCall).
        :param pulumi.Input[Sequence[pulumi.Input['ContactPointWebexArgs']]] webexes: A contact point that sends notifications to Cisco Webex.
        :param pulumi.Input[Sequence[pulumi.Input['ContactPointWebhookArgs']]] webhooks: A contact point that sends notifications to an arbitrary webhook, using the Prometheus webhook format defined here: https://prometheus.io/docs/alerting/latest/configuration/#webhook_config
        :param pulumi.Input[Sequence[pulumi.Input['ContactPointWecomArgs']]] wecoms: A contact point that sends notifications to WeCom.
        """
        if alertmanagers is not None:
            pulumi.set(__self__, "alertmanagers", alertmanagers)
        if dingdings is not None:
            pulumi.set(__self__, "dingdings", dingdings)
        if disable_provenance is not None:
            pulumi.set(__self__, "disable_provenance", disable_provenance)
        if discords is not None:
            pulumi.set(__self__, "discords", discords)
        if emails is not None:
            pulumi.set(__self__, "emails", emails)
        if googlechats is not None:
            pulumi.set(__self__, "googlechats", googlechats)
        if kafkas is not None:
            pulumi.set(__self__, "kafkas", kafkas)
        if lines is not None:
            pulumi.set(__self__, "lines", lines)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if oncalls is not None:
            pulumi.set(__self__, "oncalls", oncalls)
        if opsgenies is not None:
            pulumi.set(__self__, "opsgenies", opsgenies)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if pagerduties is not None:
            pulumi.set(__self__, "pagerduties", pagerduties)
        if pushovers is not None:
            pulumi.set(__self__, "pushovers", pushovers)
        if sensugos is not None:
            pulumi.set(__self__, "sensugos", sensugos)
        if slacks is not None:
            pulumi.set(__self__, "slacks", slacks)
        if sns is not None:
            pulumi.set(__self__, "sns", sns)
        if teams is not None:
            pulumi.set(__self__, "teams", teams)
        if telegrams is not None:
            pulumi.set(__self__, "telegrams", telegrams)
        if threemas is not None:
            pulumi.set(__self__, "threemas", threemas)
        if victorops is not None:
            pulumi.set(__self__, "victorops", victorops)
        if webexes is not None:
            pulumi.set(__self__, "webexes", webexes)
        if webhooks is not None:
            pulumi.set(__self__, "webhooks", webhooks)
        if wecoms is not None:
            pulumi.set(__self__, "wecoms", wecoms)

    @property
    @pulumi.getter
    def alertmanagers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointAlertmanagerArgs']]]]:
        """
        A contact point that sends notifications to other Alertmanager instances.
        """
        return pulumi.get(self, "alertmanagers")

    @alertmanagers.setter
    def alertmanagers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointAlertmanagerArgs']]]]):
        pulumi.set(self, "alertmanagers", value)

    @property
    @pulumi.getter
    def dingdings(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointDingdingArgs']]]]:
        """
        A contact point that sends notifications to DingDing.
        """
        return pulumi.get(self, "dingdings")

    @dingdings.setter
    def dingdings(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointDingdingArgs']]]]):
        pulumi.set(self, "dingdings", value)

    @property
    @pulumi.getter(name="disableProvenance")
    def disable_provenance(self) -> Optional[pulumi.Input[builtins.bool]]:
        return pulumi.get(self, "disable_provenance")

    @disable_provenance.setter
    def disable_provenance(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "disable_provenance", value)

    @property
    @pulumi.getter
    def discords(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointDiscordArgs']]]]:
        """
        A contact point that sends notifications as Discord messages
        """
        return pulumi.get(self, "discords")

    @discords.setter
    def discords(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointDiscordArgs']]]]):
        pulumi.set(self, "discords", value)

    @property
    @pulumi.getter
    def emails(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointEmailArgs']]]]:
        """
        A contact point that sends notifications to an email address.
        """
        return pulumi.get(self, "emails")

    @emails.setter
    def emails(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointEmailArgs']]]]):
        pulumi.set(self, "emails", value)

    @property
    @pulumi.getter
    def googlechats(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointGooglechatArgs']]]]:
        """
        A contact point that sends notifications to Google Chat.
        """
        return pulumi.get(self, "googlechats")

    @googlechats.setter
    def googlechats(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointGooglechatArgs']]]]):
        pulumi.set(self, "googlechats", value)

    @property
    @pulumi.getter
    def kafkas(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointKafkaArgs']]]]:
        """
        A contact point that publishes notifications to Apache Kafka topics.
        """
        return pulumi.get(self, "kafkas")

    @kafkas.setter
    def kafkas(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointKafkaArgs']]]]):
        pulumi.set(self, "kafkas", value)

    @property
    @pulumi.getter
    def lines(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointLineArgs']]]]:
        """
        A contact point that sends notifications to LINE.me.
        """
        return pulumi.get(self, "lines")

    @lines.setter
    def lines(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointLineArgs']]]]):
        pulumi.set(self, "lines", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the contact point.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def oncalls(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointOncallArgs']]]]:
        """
        A contact point that sends notifications to Grafana On-Call.
        """
        return pulumi.get(self, "oncalls")

    @oncalls.setter
    def oncalls(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointOncallArgs']]]]):
        pulumi.set(self, "oncalls", value)

    @property
    @pulumi.getter
    def opsgenies(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointOpsgenyArgs']]]]:
        """
        A contact point that sends notifications to OpsGenie.
        """
        return pulumi.get(self, "opsgenies")

    @opsgenies.setter
    def opsgenies(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointOpsgenyArgs']]]]):
        pulumi.set(self, "opsgenies", value)

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The Organization ID. If not set, the Org ID defined in the provider block will be used.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "org_id", value)

    @property
    @pulumi.getter
    def pagerduties(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointPagerdutyArgs']]]]:
        """
        A contact point that sends notifications to PagerDuty.
        """
        return pulumi.get(self, "pagerduties")

    @pagerduties.setter
    def pagerduties(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointPagerdutyArgs']]]]):
        pulumi.set(self, "pagerduties", value)

    @property
    @pulumi.getter
    def pushovers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointPushoverArgs']]]]:
        """
        A contact point that sends notifications to Pushover.
        """
        return pulumi.get(self, "pushovers")

    @pushovers.setter
    def pushovers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointPushoverArgs']]]]):
        pulumi.set(self, "pushovers", value)

    @property
    @pulumi.getter
    def sensugos(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointSensugoArgs']]]]:
        """
        A contact point that sends notifications to SensuGo.
        """
        return pulumi.get(self, "sensugos")

    @sensugos.setter
    def sensugos(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointSensugoArgs']]]]):
        pulumi.set(self, "sensugos", value)

    @property
    @pulumi.getter
    def slacks(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointSlackArgs']]]]:
        """
        A contact point that sends notifications to Slack.
        """
        return pulumi.get(self, "slacks")

    @slacks.setter
    def slacks(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointSlackArgs']]]]):
        pulumi.set(self, "slacks", value)

    @property
    @pulumi.getter
    def sns(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointSnArgs']]]]:
        """
        A contact point that sends notifications to Amazon SNS. Requires Amazon Managed Grafana.
        """
        return pulumi.get(self, "sns")

    @sns.setter
    def sns(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointSnArgs']]]]):
        pulumi.set(self, "sns", value)

    @property
    @pulumi.getter
    def teams(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointTeamArgs']]]]:
        """
        A contact point that sends notifications to Microsoft Teams.
        """
        return pulumi.get(self, "teams")

    @teams.setter
    def teams(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointTeamArgs']]]]):
        pulumi.set(self, "teams", value)

    @property
    @pulumi.getter
    def telegrams(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointTelegramArgs']]]]:
        """
        A contact point that sends notifications to Telegram.
        """
        return pulumi.get(self, "telegrams")

    @telegrams.setter
    def telegrams(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointTelegramArgs']]]]):
        pulumi.set(self, "telegrams", value)

    @property
    @pulumi.getter
    def threemas(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointThreemaArgs']]]]:
        """
        A contact point that sends notifications to Threema.
        """
        return pulumi.get(self, "threemas")

    @threemas.setter
    def threemas(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointThreemaArgs']]]]):
        pulumi.set(self, "threemas", value)

    @property
    @pulumi.getter
    def victorops(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointVictoropArgs']]]]:
        """
        A contact point that sends notifications to VictorOps (now known as Splunk OnCall).
        """
        return pulumi.get(self, "victorops")

    @victorops.setter
    def victorops(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointVictoropArgs']]]]):
        pulumi.set(self, "victorops", value)

    @property
    @pulumi.getter
    def webexes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointWebexArgs']]]]:
        """
        A contact point that sends notifications to Cisco Webex.
        """
        return pulumi.get(self, "webexes")

    @webexes.setter
    def webexes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointWebexArgs']]]]):
        pulumi.set(self, "webexes", value)

    @property
    @pulumi.getter
    def webhooks(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointWebhookArgs']]]]:
        """
        A contact point that sends notifications to an arbitrary webhook, using the Prometheus webhook format defined here: https://prometheus.io/docs/alerting/latest/configuration/#webhook_config
        """
        return pulumi.get(self, "webhooks")

    @webhooks.setter
    def webhooks(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointWebhookArgs']]]]):
        pulumi.set(self, "webhooks", value)

    @property
    @pulumi.getter
    def wecoms(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointWecomArgs']]]]:
        """
        A contact point that sends notifications to WeCom.
        """
        return pulumi.get(self, "wecoms")

    @wecoms.setter
    def wecoms(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ContactPointWecomArgs']]]]):
        pulumi.set(self, "wecoms", value)


warnings.warn("""grafana.index/contactpoint.ContactPoint has been deprecated in favor of grafana.alerting/contactpoint.ContactPoint""", DeprecationWarning)


@pulumi.type_token("grafana:index/contactPoint:ContactPoint")
class ContactPoint(pulumi.CustomResource):
    warnings.warn("""grafana.index/contactpoint.ContactPoint has been deprecated in favor of grafana.alerting/contactpoint.ContactPoint""", DeprecationWarning)

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 alertmanagers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointAlertmanagerArgs', 'ContactPointAlertmanagerArgsDict']]]]] = None,
                 dingdings: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointDingdingArgs', 'ContactPointDingdingArgsDict']]]]] = None,
                 disable_provenance: Optional[pulumi.Input[builtins.bool]] = None,
                 discords: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointDiscordArgs', 'ContactPointDiscordArgsDict']]]]] = None,
                 emails: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointEmailArgs', 'ContactPointEmailArgsDict']]]]] = None,
                 googlechats: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointGooglechatArgs', 'ContactPointGooglechatArgsDict']]]]] = None,
                 kafkas: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointKafkaArgs', 'ContactPointKafkaArgsDict']]]]] = None,
                 lines: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointLineArgs', 'ContactPointLineArgsDict']]]]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 oncalls: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointOncallArgs', 'ContactPointOncallArgsDict']]]]] = None,
                 opsgenies: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointOpsgenyArgs', 'ContactPointOpsgenyArgsDict']]]]] = None,
                 org_id: Optional[pulumi.Input[builtins.str]] = None,
                 pagerduties: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointPagerdutyArgs', 'ContactPointPagerdutyArgsDict']]]]] = None,
                 pushovers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointPushoverArgs', 'ContactPointPushoverArgsDict']]]]] = None,
                 sensugos: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointSensugoArgs', 'ContactPointSensugoArgsDict']]]]] = None,
                 slacks: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointSlackArgs', 'ContactPointSlackArgsDict']]]]] = None,
                 sns: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointSnArgs', 'ContactPointSnArgsDict']]]]] = None,
                 teams: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointTeamArgs', 'ContactPointTeamArgsDict']]]]] = None,
                 telegrams: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointTelegramArgs', 'ContactPointTelegramArgsDict']]]]] = None,
                 threemas: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointThreemaArgs', 'ContactPointThreemaArgsDict']]]]] = None,
                 victorops: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointVictoropArgs', 'ContactPointVictoropArgsDict']]]]] = None,
                 webexes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointWebexArgs', 'ContactPointWebexArgsDict']]]]] = None,
                 webhooks: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointWebhookArgs', 'ContactPointWebhookArgsDict']]]]] = None,
                 wecoms: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointWecomArgs', 'ContactPointWecomArgsDict']]]]] = None,
                 __props__=None):
        """
        Manages Grafana Alerting contact points.

        * Official documentation
        * [HTTP API](https://grafana.com/docs/grafana/latest/developers/http_api/alerting_provisioning/#contact-points)

        This resource requires Grafana 9.1.0 or later.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_grafana as grafana

        my_contact_point = grafana.alerting.ContactPoint("my_contact_point",
            name="My Contact Point",
            emails=[{
                "addresses": [
                    "one@company.org",
                    "two@company.org",
                ],
                "message": "{{ len .Alerts.Firing }} firing.",
                "subject": "{{ template \\"default.title\\" .}}",
                "single_email": True,
                "disable_resolve_message": False,
            }])
        ```

        ## Import

        ```sh
        $ pulumi import grafana:index/contactPoint:ContactPoint name "{{ name }}"
        ```

        ```sh
        $ pulumi import grafana:index/contactPoint:ContactPoint name "{{ orgID }}:{{ name }}"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ContactPointAlertmanagerArgs', 'ContactPointAlertmanagerArgsDict']]]] alertmanagers: A contact point that sends notifications to other Alertmanager instances.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ContactPointDingdingArgs', 'ContactPointDingdingArgsDict']]]] dingdings: A contact point that sends notifications to DingDing.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ContactPointDiscordArgs', 'ContactPointDiscordArgsDict']]]] discords: A contact point that sends notifications as Discord messages
        :param pulumi.Input[Sequence[pulumi.Input[Union['ContactPointEmailArgs', 'ContactPointEmailArgsDict']]]] emails: A contact point that sends notifications to an email address.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ContactPointGooglechatArgs', 'ContactPointGooglechatArgsDict']]]] googlechats: A contact point that sends notifications to Google Chat.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ContactPointKafkaArgs', 'ContactPointKafkaArgsDict']]]] kafkas: A contact point that publishes notifications to Apache Kafka topics.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ContactPointLineArgs', 'ContactPointLineArgsDict']]]] lines: A contact point that sends notifications to LINE.me.
        :param pulumi.Input[builtins.str] name: The name of the contact point.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ContactPointOncallArgs', 'ContactPointOncallArgsDict']]]] oncalls: A contact point that sends notifications to Grafana On-Call.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ContactPointOpsgenyArgs', 'ContactPointOpsgenyArgsDict']]]] opsgenies: A contact point that sends notifications to OpsGenie.
        :param pulumi.Input[builtins.str] org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ContactPointPagerdutyArgs', 'ContactPointPagerdutyArgsDict']]]] pagerduties: A contact point that sends notifications to PagerDuty.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ContactPointPushoverArgs', 'ContactPointPushoverArgsDict']]]] pushovers: A contact point that sends notifications to Pushover.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ContactPointSensugoArgs', 'ContactPointSensugoArgsDict']]]] sensugos: A contact point that sends notifications to SensuGo.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ContactPointSlackArgs', 'ContactPointSlackArgsDict']]]] slacks: A contact point that sends notifications to Slack.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ContactPointSnArgs', 'ContactPointSnArgsDict']]]] sns: A contact point that sends notifications to Amazon SNS. Requires Amazon Managed Grafana.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ContactPointTeamArgs', 'ContactPointTeamArgsDict']]]] teams: A contact point that sends notifications to Microsoft Teams.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ContactPointTelegramArgs', 'ContactPointTelegramArgsDict']]]] telegrams: A contact point that sends notifications to Telegram.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ContactPointThreemaArgs', 'ContactPointThreemaArgsDict']]]] threemas: A contact point that sends notifications to Threema.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ContactPointVictoropArgs', 'ContactPointVictoropArgsDict']]]] victorops: A contact point that sends notifications to VictorOps (now known as Splunk OnCall).
        :param pulumi.Input[Sequence[pulumi.Input[Union['ContactPointWebexArgs', 'ContactPointWebexArgsDict']]]] webexes: A contact point that sends notifications to Cisco Webex.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ContactPointWebhookArgs', 'ContactPointWebhookArgsDict']]]] webhooks: A contact point that sends notifications to an arbitrary webhook, using the Prometheus webhook format defined here: https://prometheus.io/docs/alerting/latest/configuration/#webhook_config
        :param pulumi.Input[Sequence[pulumi.Input[Union['ContactPointWecomArgs', 'ContactPointWecomArgsDict']]]] wecoms: A contact point that sends notifications to WeCom.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ContactPointArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages Grafana Alerting contact points.

        * Official documentation
        * [HTTP API](https://grafana.com/docs/grafana/latest/developers/http_api/alerting_provisioning/#contact-points)

        This resource requires Grafana 9.1.0 or later.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_grafana as grafana

        my_contact_point = grafana.alerting.ContactPoint("my_contact_point",
            name="My Contact Point",
            emails=[{
                "addresses": [
                    "one@company.org",
                    "two@company.org",
                ],
                "message": "{{ len .Alerts.Firing }} firing.",
                "subject": "{{ template \\"default.title\\" .}}",
                "single_email": True,
                "disable_resolve_message": False,
            }])
        ```

        ## Import

        ```sh
        $ pulumi import grafana:index/contactPoint:ContactPoint name "{{ name }}"
        ```

        ```sh
        $ pulumi import grafana:index/contactPoint:ContactPoint name "{{ orgID }}:{{ name }}"
        ```

        :param str resource_name: The name of the resource.
        :param ContactPointArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ContactPointArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 alertmanagers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointAlertmanagerArgs', 'ContactPointAlertmanagerArgsDict']]]]] = None,
                 dingdings: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointDingdingArgs', 'ContactPointDingdingArgsDict']]]]] = None,
                 disable_provenance: Optional[pulumi.Input[builtins.bool]] = None,
                 discords: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointDiscordArgs', 'ContactPointDiscordArgsDict']]]]] = None,
                 emails: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointEmailArgs', 'ContactPointEmailArgsDict']]]]] = None,
                 googlechats: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointGooglechatArgs', 'ContactPointGooglechatArgsDict']]]]] = None,
                 kafkas: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointKafkaArgs', 'ContactPointKafkaArgsDict']]]]] = None,
                 lines: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointLineArgs', 'ContactPointLineArgsDict']]]]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 oncalls: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointOncallArgs', 'ContactPointOncallArgsDict']]]]] = None,
                 opsgenies: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointOpsgenyArgs', 'ContactPointOpsgenyArgsDict']]]]] = None,
                 org_id: Optional[pulumi.Input[builtins.str]] = None,
                 pagerduties: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointPagerdutyArgs', 'ContactPointPagerdutyArgsDict']]]]] = None,
                 pushovers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointPushoverArgs', 'ContactPointPushoverArgsDict']]]]] = None,
                 sensugos: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointSensugoArgs', 'ContactPointSensugoArgsDict']]]]] = None,
                 slacks: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointSlackArgs', 'ContactPointSlackArgsDict']]]]] = None,
                 sns: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointSnArgs', 'ContactPointSnArgsDict']]]]] = None,
                 teams: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointTeamArgs', 'ContactPointTeamArgsDict']]]]] = None,
                 telegrams: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointTelegramArgs', 'ContactPointTelegramArgsDict']]]]] = None,
                 threemas: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointThreemaArgs', 'ContactPointThreemaArgsDict']]]]] = None,
                 victorops: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointVictoropArgs', 'ContactPointVictoropArgsDict']]]]] = None,
                 webexes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointWebexArgs', 'ContactPointWebexArgsDict']]]]] = None,
                 webhooks: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointWebhookArgs', 'ContactPointWebhookArgsDict']]]]] = None,
                 wecoms: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointWecomArgs', 'ContactPointWecomArgsDict']]]]] = None,
                 __props__=None):
        pulumi.log.warn("""ContactPoint is deprecated: grafana.index/contactpoint.ContactPoint has been deprecated in favor of grafana.alerting/contactpoint.ContactPoint""")
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ContactPointArgs.__new__(ContactPointArgs)

            __props__.__dict__["alertmanagers"] = alertmanagers
            __props__.__dict__["dingdings"] = dingdings
            __props__.__dict__["disable_provenance"] = disable_provenance
            __props__.__dict__["discords"] = discords
            __props__.__dict__["emails"] = emails
            __props__.__dict__["googlechats"] = googlechats
            __props__.__dict__["kafkas"] = kafkas
            __props__.__dict__["lines"] = lines
            __props__.__dict__["name"] = name
            __props__.__dict__["oncalls"] = oncalls
            __props__.__dict__["opsgenies"] = opsgenies
            __props__.__dict__["org_id"] = org_id
            __props__.__dict__["pagerduties"] = pagerduties
            __props__.__dict__["pushovers"] = pushovers
            __props__.__dict__["sensugos"] = sensugos
            __props__.__dict__["slacks"] = slacks
            __props__.__dict__["sns"] = sns
            __props__.__dict__["teams"] = teams
            __props__.__dict__["telegrams"] = telegrams
            __props__.__dict__["threemas"] = threemas
            __props__.__dict__["victorops"] = victorops
            __props__.__dict__["webexes"] = webexes
            __props__.__dict__["webhooks"] = webhooks
            __props__.__dict__["wecoms"] = wecoms
        alias_opts = pulumi.ResourceOptions(aliases=[pulumi.Alias(type_="grafana:index/contactPoint:ContactPoint")])
        opts = pulumi.ResourceOptions.merge(opts, alias_opts)
        super(ContactPoint, __self__).__init__(
            'grafana:index/contactPoint:ContactPoint',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            alertmanagers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointAlertmanagerArgs', 'ContactPointAlertmanagerArgsDict']]]]] = None,
            dingdings: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointDingdingArgs', 'ContactPointDingdingArgsDict']]]]] = None,
            disable_provenance: Optional[pulumi.Input[builtins.bool]] = None,
            discords: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointDiscordArgs', 'ContactPointDiscordArgsDict']]]]] = None,
            emails: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointEmailArgs', 'ContactPointEmailArgsDict']]]]] = None,
            googlechats: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointGooglechatArgs', 'ContactPointGooglechatArgsDict']]]]] = None,
            kafkas: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointKafkaArgs', 'ContactPointKafkaArgsDict']]]]] = None,
            lines: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointLineArgs', 'ContactPointLineArgsDict']]]]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            oncalls: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointOncallArgs', 'ContactPointOncallArgsDict']]]]] = None,
            opsgenies: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointOpsgenyArgs', 'ContactPointOpsgenyArgsDict']]]]] = None,
            org_id: Optional[pulumi.Input[builtins.str]] = None,
            pagerduties: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointPagerdutyArgs', 'ContactPointPagerdutyArgsDict']]]]] = None,
            pushovers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointPushoverArgs', 'ContactPointPushoverArgsDict']]]]] = None,
            sensugos: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointSensugoArgs', 'ContactPointSensugoArgsDict']]]]] = None,
            slacks: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointSlackArgs', 'ContactPointSlackArgsDict']]]]] = None,
            sns: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointSnArgs', 'ContactPointSnArgsDict']]]]] = None,
            teams: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointTeamArgs', 'ContactPointTeamArgsDict']]]]] = None,
            telegrams: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointTelegramArgs', 'ContactPointTelegramArgsDict']]]]] = None,
            threemas: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointThreemaArgs', 'ContactPointThreemaArgsDict']]]]] = None,
            victorops: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointVictoropArgs', 'ContactPointVictoropArgsDict']]]]] = None,
            webexes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointWebexArgs', 'ContactPointWebexArgsDict']]]]] = None,
            webhooks: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointWebhookArgs', 'ContactPointWebhookArgsDict']]]]] = None,
            wecoms: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContactPointWecomArgs', 'ContactPointWecomArgsDict']]]]] = None) -> 'ContactPoint':
        """
        Get an existing ContactPoint resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ContactPointAlertmanagerArgs', 'ContactPointAlertmanagerArgsDict']]]] alertmanagers: A contact point that sends notifications to other Alertmanager instances.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ContactPointDingdingArgs', 'ContactPointDingdingArgsDict']]]] dingdings: A contact point that sends notifications to DingDing.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ContactPointDiscordArgs', 'ContactPointDiscordArgsDict']]]] discords: A contact point that sends notifications as Discord messages
        :param pulumi.Input[Sequence[pulumi.Input[Union['ContactPointEmailArgs', 'ContactPointEmailArgsDict']]]] emails: A contact point that sends notifications to an email address.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ContactPointGooglechatArgs', 'ContactPointGooglechatArgsDict']]]] googlechats: A contact point that sends notifications to Google Chat.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ContactPointKafkaArgs', 'ContactPointKafkaArgsDict']]]] kafkas: A contact point that publishes notifications to Apache Kafka topics.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ContactPointLineArgs', 'ContactPointLineArgsDict']]]] lines: A contact point that sends notifications to LINE.me.
        :param pulumi.Input[builtins.str] name: The name of the contact point.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ContactPointOncallArgs', 'ContactPointOncallArgsDict']]]] oncalls: A contact point that sends notifications to Grafana On-Call.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ContactPointOpsgenyArgs', 'ContactPointOpsgenyArgsDict']]]] opsgenies: A contact point that sends notifications to OpsGenie.
        :param pulumi.Input[builtins.str] org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ContactPointPagerdutyArgs', 'ContactPointPagerdutyArgsDict']]]] pagerduties: A contact point that sends notifications to PagerDuty.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ContactPointPushoverArgs', 'ContactPointPushoverArgsDict']]]] pushovers: A contact point that sends notifications to Pushover.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ContactPointSensugoArgs', 'ContactPointSensugoArgsDict']]]] sensugos: A contact point that sends notifications to SensuGo.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ContactPointSlackArgs', 'ContactPointSlackArgsDict']]]] slacks: A contact point that sends notifications to Slack.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ContactPointSnArgs', 'ContactPointSnArgsDict']]]] sns: A contact point that sends notifications to Amazon SNS. Requires Amazon Managed Grafana.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ContactPointTeamArgs', 'ContactPointTeamArgsDict']]]] teams: A contact point that sends notifications to Microsoft Teams.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ContactPointTelegramArgs', 'ContactPointTelegramArgsDict']]]] telegrams: A contact point that sends notifications to Telegram.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ContactPointThreemaArgs', 'ContactPointThreemaArgsDict']]]] threemas: A contact point that sends notifications to Threema.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ContactPointVictoropArgs', 'ContactPointVictoropArgsDict']]]] victorops: A contact point that sends notifications to VictorOps (now known as Splunk OnCall).
        :param pulumi.Input[Sequence[pulumi.Input[Union['ContactPointWebexArgs', 'ContactPointWebexArgsDict']]]] webexes: A contact point that sends notifications to Cisco Webex.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ContactPointWebhookArgs', 'ContactPointWebhookArgsDict']]]] webhooks: A contact point that sends notifications to an arbitrary webhook, using the Prometheus webhook format defined here: https://prometheus.io/docs/alerting/latest/configuration/#webhook_config
        :param pulumi.Input[Sequence[pulumi.Input[Union['ContactPointWecomArgs', 'ContactPointWecomArgsDict']]]] wecoms: A contact point that sends notifications to WeCom.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ContactPointState.__new__(_ContactPointState)

        __props__.__dict__["alertmanagers"] = alertmanagers
        __props__.__dict__["dingdings"] = dingdings
        __props__.__dict__["disable_provenance"] = disable_provenance
        __props__.__dict__["discords"] = discords
        __props__.__dict__["emails"] = emails
        __props__.__dict__["googlechats"] = googlechats
        __props__.__dict__["kafkas"] = kafkas
        __props__.__dict__["lines"] = lines
        __props__.__dict__["name"] = name
        __props__.__dict__["oncalls"] = oncalls
        __props__.__dict__["opsgenies"] = opsgenies
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["pagerduties"] = pagerduties
        __props__.__dict__["pushovers"] = pushovers
        __props__.__dict__["sensugos"] = sensugos
        __props__.__dict__["slacks"] = slacks
        __props__.__dict__["sns"] = sns
        __props__.__dict__["teams"] = teams
        __props__.__dict__["telegrams"] = telegrams
        __props__.__dict__["threemas"] = threemas
        __props__.__dict__["victorops"] = victorops
        __props__.__dict__["webexes"] = webexes
        __props__.__dict__["webhooks"] = webhooks
        __props__.__dict__["wecoms"] = wecoms
        return ContactPoint(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def alertmanagers(self) -> pulumi.Output[Optional[Sequence['outputs.ContactPointAlertmanager']]]:
        """
        A contact point that sends notifications to other Alertmanager instances.
        """
        return pulumi.get(self, "alertmanagers")

    @property
    @pulumi.getter
    def dingdings(self) -> pulumi.Output[Optional[Sequence['outputs.ContactPointDingding']]]:
        """
        A contact point that sends notifications to DingDing.
        """
        return pulumi.get(self, "dingdings")

    @property
    @pulumi.getter(name="disableProvenance")
    def disable_provenance(self) -> pulumi.Output[Optional[builtins.bool]]:
        return pulumi.get(self, "disable_provenance")

    @property
    @pulumi.getter
    def discords(self) -> pulumi.Output[Optional[Sequence['outputs.ContactPointDiscord']]]:
        """
        A contact point that sends notifications as Discord messages
        """
        return pulumi.get(self, "discords")

    @property
    @pulumi.getter
    def emails(self) -> pulumi.Output[Optional[Sequence['outputs.ContactPointEmail']]]:
        """
        A contact point that sends notifications to an email address.
        """
        return pulumi.get(self, "emails")

    @property
    @pulumi.getter
    def googlechats(self) -> pulumi.Output[Optional[Sequence['outputs.ContactPointGooglechat']]]:
        """
        A contact point that sends notifications to Google Chat.
        """
        return pulumi.get(self, "googlechats")

    @property
    @pulumi.getter
    def kafkas(self) -> pulumi.Output[Optional[Sequence['outputs.ContactPointKafka']]]:
        """
        A contact point that publishes notifications to Apache Kafka topics.
        """
        return pulumi.get(self, "kafkas")

    @property
    @pulumi.getter
    def lines(self) -> pulumi.Output[Optional[Sequence['outputs.ContactPointLine']]]:
        """
        A contact point that sends notifications to LINE.me.
        """
        return pulumi.get(self, "lines")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        The name of the contact point.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def oncalls(self) -> pulumi.Output[Optional[Sequence['outputs.ContactPointOncall']]]:
        """
        A contact point that sends notifications to Grafana On-Call.
        """
        return pulumi.get(self, "oncalls")

    @property
    @pulumi.getter
    def opsgenies(self) -> pulumi.Output[Optional[Sequence['outputs.ContactPointOpsgeny']]]:
        """
        A contact point that sends notifications to OpsGenie.
        """
        return pulumi.get(self, "opsgenies")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The Organization ID. If not set, the Org ID defined in the provider block will be used.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter
    def pagerduties(self) -> pulumi.Output[Optional[Sequence['outputs.ContactPointPagerduty']]]:
        """
        A contact point that sends notifications to PagerDuty.
        """
        return pulumi.get(self, "pagerduties")

    @property
    @pulumi.getter
    def pushovers(self) -> pulumi.Output[Optional[Sequence['outputs.ContactPointPushover']]]:
        """
        A contact point that sends notifications to Pushover.
        """
        return pulumi.get(self, "pushovers")

    @property
    @pulumi.getter
    def sensugos(self) -> pulumi.Output[Optional[Sequence['outputs.ContactPointSensugo']]]:
        """
        A contact point that sends notifications to SensuGo.
        """
        return pulumi.get(self, "sensugos")

    @property
    @pulumi.getter
    def slacks(self) -> pulumi.Output[Optional[Sequence['outputs.ContactPointSlack']]]:
        """
        A contact point that sends notifications to Slack.
        """
        return pulumi.get(self, "slacks")

    @property
    @pulumi.getter
    def sns(self) -> pulumi.Output[Optional[Sequence['outputs.ContactPointSn']]]:
        """
        A contact point that sends notifications to Amazon SNS. Requires Amazon Managed Grafana.
        """
        return pulumi.get(self, "sns")

    @property
    @pulumi.getter
    def teams(self) -> pulumi.Output[Optional[Sequence['outputs.ContactPointTeam']]]:
        """
        A contact point that sends notifications to Microsoft Teams.
        """
        return pulumi.get(self, "teams")

    @property
    @pulumi.getter
    def telegrams(self) -> pulumi.Output[Optional[Sequence['outputs.ContactPointTelegram']]]:
        """
        A contact point that sends notifications to Telegram.
        """
        return pulumi.get(self, "telegrams")

    @property
    @pulumi.getter
    def threemas(self) -> pulumi.Output[Optional[Sequence['outputs.ContactPointThreema']]]:
        """
        A contact point that sends notifications to Threema.
        """
        return pulumi.get(self, "threemas")

    @property
    @pulumi.getter
    def victorops(self) -> pulumi.Output[Optional[Sequence['outputs.ContactPointVictorop']]]:
        """
        A contact point that sends notifications to VictorOps (now known as Splunk OnCall).
        """
        return pulumi.get(self, "victorops")

    @property
    @pulumi.getter
    def webexes(self) -> pulumi.Output[Optional[Sequence['outputs.ContactPointWebex']]]:
        """
        A contact point that sends notifications to Cisco Webex.
        """
        return pulumi.get(self, "webexes")

    @property
    @pulumi.getter
    def webhooks(self) -> pulumi.Output[Optional[Sequence['outputs.ContactPointWebhook']]]:
        """
        A contact point that sends notifications to an arbitrary webhook, using the Prometheus webhook format defined here: https://prometheus.io/docs/alerting/latest/configuration/#webhook_config
        """
        return pulumi.get(self, "webhooks")

    @property
    @pulumi.getter
    def wecoms(self) -> pulumi.Output[Optional[Sequence['outputs.ContactPointWecom']]]:
        """
        A contact point that sends notifications to WeCom.
        """
        return pulumi.get(self, "wecoms")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ProjectArgs', 'Project']

@pulumi.input_type
class ProjectArgs:
    def __init__(__self__, *,
                 name: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Project resource.
        :param pulumi.Input[builtins.str] name: Human-friendly identifier of the project.
        """
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Human-friendly identifier of the project.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _ProjectState:
    def __init__(__self__, *,
                 created: Optional[pulumi.Input[builtins.str]] = None,
                 grafana_folder_uid: Optional[pulumi.Input[builtins.str]] = None,
                 is_default: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 updated: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Project resources.
        :param pulumi.Input[builtins.str] created: The date when the project was created.
        :param pulumi.Input[builtins.str] grafana_folder_uid: The Grafana folder uid.
        :param pulumi.Input[builtins.bool] is_default: Use this project as default for running tests when no explicit project identifier is provided.
        :param pulumi.Input[builtins.str] name: Human-friendly identifier of the project.
        :param pulumi.Input[builtins.str] updated: The date when the project was last updated.
        """
        if created is not None:
            pulumi.set(__self__, "created", created)
        if grafana_folder_uid is not None:
            pulumi.set(__self__, "grafana_folder_uid", grafana_folder_uid)
        if is_default is not None:
            pulumi.set(__self__, "is_default", is_default)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if updated is not None:
            pulumi.set(__self__, "updated", updated)

    @property
    @pulumi.getter
    def created(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The date when the project was created.
        """
        return pulumi.get(self, "created")

    @created.setter
    def created(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created", value)

    @property
    @pulumi.getter(name="grafanaFolderUid")
    def grafana_folder_uid(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The Grafana folder uid.
        """
        return pulumi.get(self, "grafana_folder_uid")

    @grafana_folder_uid.setter
    def grafana_folder_uid(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "grafana_folder_uid", value)

    @property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Use this project as default for running tests when no explicit project identifier is provided.
        """
        return pulumi.get(self, "is_default")

    @is_default.setter
    def is_default(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "is_default", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Human-friendly identifier of the project.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def updated(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The date when the project was last updated.
        """
        return pulumi.get(self, "updated")

    @updated.setter
    def updated(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated", value)


@pulumi.type_token("grafana:k6/project:Project")
class Project(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Manages a k6 project.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_grafana as grafana

        test_project = grafana.k6.Project("test_project", name="Terraform Test Project")
        ```

        ## Import

        ```sh
        $ pulumi import grafana:k6/project:Project name "{{ id }}"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] name: Human-friendly identifier of the project.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ProjectArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a k6 project.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_grafana as grafana

        test_project = grafana.k6.Project("test_project", name="Terraform Test Project")
        ```

        ## Import

        ```sh
        $ pulumi import grafana:k6/project:Project name "{{ id }}"
        ```

        :param str resource_name: The name of the resource.
        :param ProjectArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProjectArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProjectArgs.__new__(ProjectArgs)

            __props__.__dict__["name"] = name
            __props__.__dict__["created"] = None
            __props__.__dict__["grafana_folder_uid"] = None
            __props__.__dict__["is_default"] = None
            __props__.__dict__["updated"] = None
        super(Project, __self__).__init__(
            'grafana:k6/project:Project',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created: Optional[pulumi.Input[builtins.str]] = None,
            grafana_folder_uid: Optional[pulumi.Input[builtins.str]] = None,
            is_default: Optional[pulumi.Input[builtins.bool]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            updated: Optional[pulumi.Input[builtins.str]] = None) -> 'Project':
        """
        Get an existing Project resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] created: The date when the project was created.
        :param pulumi.Input[builtins.str] grafana_folder_uid: The Grafana folder uid.
        :param pulumi.Input[builtins.bool] is_default: Use this project as default for running tests when no explicit project identifier is provided.
        :param pulumi.Input[builtins.str] name: Human-friendly identifier of the project.
        :param pulumi.Input[builtins.str] updated: The date when the project was last updated.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProjectState.__new__(_ProjectState)

        __props__.__dict__["created"] = created
        __props__.__dict__["grafana_folder_uid"] = grafana_folder_uid
        __props__.__dict__["is_default"] = is_default
        __props__.__dict__["name"] = name
        __props__.__dict__["updated"] = updated
        return Project(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def created(self) -> pulumi.Output[builtins.str]:
        """
        The date when the project was created.
        """
        return pulumi.get(self, "created")

    @property
    @pulumi.getter(name="grafanaFolderUid")
    def grafana_folder_uid(self) -> pulumi.Output[builtins.str]:
        """
        The Grafana folder uid.
        """
        return pulumi.get(self, "grafana_folder_uid")

    @property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> pulumi.Output[builtins.bool]:
        """
        Use this project as default for running tests when no explicit project identifier is provided.
        """
        return pulumi.get(self, "is_default")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        Human-friendly identifier of the project.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def updated(self) -> pulumi.Output[builtins.str]:
        """
        The date when the project was last updated.
        """
        return pulumi.get(self, "updated")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ProjectLimitsArgs', 'ProjectLimits']

@pulumi.input_type
class ProjectLimitsArgs:
    def __init__(__self__, *,
                 project_id: pulumi.Input[builtins.str],
                 duration_max_per_test: Optional[pulumi.Input[builtins.int]] = None,
                 vu_browser_max_per_test: Optional[pulumi.Input[builtins.int]] = None,
                 vu_max_per_test: Optional[pulumi.Input[builtins.int]] = None,
                 vuh_max_per_month: Optional[pulumi.Input[builtins.int]] = None):
        """
        The set of arguments for constructing a ProjectLimits resource.
        :param pulumi.Input[builtins.str] project_id: The identifier of the project to manage limits for.
        :param pulumi.Input[builtins.int] duration_max_per_test: Maximum duration of a test in seconds.
        :param pulumi.Input[builtins.int] vu_browser_max_per_test: Maximum number of concurrent browser virtual users (VUs) used in one test.
        :param pulumi.Input[builtins.int] vu_max_per_test: Maximum number of concurrent virtual users (VUs) used in one test.
        :param pulumi.Input[builtins.int] vuh_max_per_month: Maximum amount of virtual user hours (VU/h) used per one calendar month.
        """
        pulumi.set(__self__, "project_id", project_id)
        if duration_max_per_test is not None:
            pulumi.set(__self__, "duration_max_per_test", duration_max_per_test)
        if vu_browser_max_per_test is not None:
            pulumi.set(__self__, "vu_browser_max_per_test", vu_browser_max_per_test)
        if vu_max_per_test is not None:
            pulumi.set(__self__, "vu_max_per_test", vu_max_per_test)
        if vuh_max_per_month is not None:
            pulumi.set(__self__, "vuh_max_per_month", vuh_max_per_month)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[builtins.str]:
        """
        The identifier of the project to manage limits for.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter(name="durationMaxPerTest")
    def duration_max_per_test(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Maximum duration of a test in seconds.
        """
        return pulumi.get(self, "duration_max_per_test")

    @duration_max_per_test.setter
    def duration_max_per_test(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "duration_max_per_test", value)

    @property
    @pulumi.getter(name="vuBrowserMaxPerTest")
    def vu_browser_max_per_test(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Maximum number of concurrent browser virtual users (VUs) used in one test.
        """
        return pulumi.get(self, "vu_browser_max_per_test")

    @vu_browser_max_per_test.setter
    def vu_browser_max_per_test(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "vu_browser_max_per_test", value)

    @property
    @pulumi.getter(name="vuMaxPerTest")
    def vu_max_per_test(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Maximum number of concurrent virtual users (VUs) used in one test.
        """
        return pulumi.get(self, "vu_max_per_test")

    @vu_max_per_test.setter
    def vu_max_per_test(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "vu_max_per_test", value)

    @property
    @pulumi.getter(name="vuhMaxPerMonth")
    def vuh_max_per_month(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Maximum amount of virtual user hours (VU/h) used per one calendar month.
        """
        return pulumi.get(self, "vuh_max_per_month")

    @vuh_max_per_month.setter
    def vuh_max_per_month(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "vuh_max_per_month", value)


@pulumi.input_type
class _ProjectLimitsState:
    def __init__(__self__, *,
                 duration_max_per_test: Optional[pulumi.Input[builtins.int]] = None,
                 project_id: Optional[pulumi.Input[builtins.str]] = None,
                 vu_browser_max_per_test: Optional[pulumi.Input[builtins.int]] = None,
                 vu_max_per_test: Optional[pulumi.Input[builtins.int]] = None,
                 vuh_max_per_month: Optional[pulumi.Input[builtins.int]] = None):
        """
        Input properties used for looking up and filtering ProjectLimits resources.
        :param pulumi.Input[builtins.int] duration_max_per_test: Maximum duration of a test in seconds.
        :param pulumi.Input[builtins.str] project_id: The identifier of the project to manage limits for.
        :param pulumi.Input[builtins.int] vu_browser_max_per_test: Maximum number of concurrent browser virtual users (VUs) used in one test.
        :param pulumi.Input[builtins.int] vu_max_per_test: Maximum number of concurrent virtual users (VUs) used in one test.
        :param pulumi.Input[builtins.int] vuh_max_per_month: Maximum amount of virtual user hours (VU/h) used per one calendar month.
        """
        if duration_max_per_test is not None:
            pulumi.set(__self__, "duration_max_per_test", duration_max_per_test)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if vu_browser_max_per_test is not None:
            pulumi.set(__self__, "vu_browser_max_per_test", vu_browser_max_per_test)
        if vu_max_per_test is not None:
            pulumi.set(__self__, "vu_max_per_test", vu_max_per_test)
        if vuh_max_per_month is not None:
            pulumi.set(__self__, "vuh_max_per_month", vuh_max_per_month)

    @property
    @pulumi.getter(name="durationMaxPerTest")
    def duration_max_per_test(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Maximum duration of a test in seconds.
        """
        return pulumi.get(self, "duration_max_per_test")

    @duration_max_per_test.setter
    def duration_max_per_test(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "duration_max_per_test", value)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The identifier of the project to manage limits for.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter(name="vuBrowserMaxPerTest")
    def vu_browser_max_per_test(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Maximum number of concurrent browser virtual users (VUs) used in one test.
        """
        return pulumi.get(self, "vu_browser_max_per_test")

    @vu_browser_max_per_test.setter
    def vu_browser_max_per_test(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "vu_browser_max_per_test", value)

    @property
    @pulumi.getter(name="vuMaxPerTest")
    def vu_max_per_test(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Maximum number of concurrent virtual users (VUs) used in one test.
        """
        return pulumi.get(self, "vu_max_per_test")

    @vu_max_per_test.setter
    def vu_max_per_test(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "vu_max_per_test", value)

    @property
    @pulumi.getter(name="vuhMaxPerMonth")
    def vuh_max_per_month(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Maximum amount of virtual user hours (VU/h) used per one calendar month.
        """
        return pulumi.get(self, "vuh_max_per_month")

    @vuh_max_per_month.setter
    def vuh_max_per_month(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "vuh_max_per_month", value)


@pulumi.type_token("grafana:k6/projectLimits:ProjectLimits")
class ProjectLimits(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 duration_max_per_test: Optional[pulumi.Input[builtins.int]] = None,
                 project_id: Optional[pulumi.Input[builtins.str]] = None,
                 vu_browser_max_per_test: Optional[pulumi.Input[builtins.int]] = None,
                 vu_max_per_test: Optional[pulumi.Input[builtins.int]] = None,
                 vuh_max_per_month: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        """
        Manages limits for a k6 project.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_grafana as grafana

        test_project_limits = grafana.k6.Project("test_project_limits", name="Terraform Project Test Limits")
        test_limits = grafana.k6.ProjectLimits("test_limits",
            project_id=test_project_limits.id,
            vuh_max_per_month=1000,
            vu_max_per_test=100,
            vu_browser_max_per_test=10,
            duration_max_per_test=3600)
        ```

        ## Import

        ```sh
        $ pulumi import grafana:k6/projectLimits:ProjectLimits name "{{ project_id }}"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] duration_max_per_test: Maximum duration of a test in seconds.
        :param pulumi.Input[builtins.str] project_id: The identifier of the project to manage limits for.
        :param pulumi.Input[builtins.int] vu_browser_max_per_test: Maximum number of concurrent browser virtual users (VUs) used in one test.
        :param pulumi.Input[builtins.int] vu_max_per_test: Maximum number of concurrent virtual users (VUs) used in one test.
        :param pulumi.Input[builtins.int] vuh_max_per_month: Maximum amount of virtual user hours (VU/h) used per one calendar month.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProjectLimitsArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages limits for a k6 project.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_grafana as grafana

        test_project_limits = grafana.k6.Project("test_project_limits", name="Terraform Project Test Limits")
        test_limits = grafana.k6.ProjectLimits("test_limits",
            project_id=test_project_limits.id,
            vuh_max_per_month=1000,
            vu_max_per_test=100,
            vu_browser_max_per_test=10,
            duration_max_per_test=3600)
        ```

        ## Import

        ```sh
        $ pulumi import grafana:k6/projectLimits:ProjectLimits name "{{ project_id }}"
        ```

        :param str resource_name: The name of the resource.
        :param ProjectLimitsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProjectLimitsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 duration_max_per_test: Optional[pulumi.Input[builtins.int]] = None,
                 project_id: Optional[pulumi.Input[builtins.str]] = None,
                 vu_browser_max_per_test: Optional[pulumi.Input[builtins.int]] = None,
                 vu_max_per_test: Optional[pulumi.Input[builtins.int]] = None,
                 vuh_max_per_month: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProjectLimitsArgs.__new__(ProjectLimitsArgs)

            __props__.__dict__["duration_max_per_test"] = duration_max_per_test
            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["vu_browser_max_per_test"] = vu_browser_max_per_test
            __props__.__dict__["vu_max_per_test"] = vu_max_per_test
            __props__.__dict__["vuh_max_per_month"] = vuh_max_per_month
        super(ProjectLimits, __self__).__init__(
            'grafana:k6/projectLimits:ProjectLimits',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            duration_max_per_test: Optional[pulumi.Input[builtins.int]] = None,
            project_id: Optional[pulumi.Input[builtins.str]] = None,
            vu_browser_max_per_test: Optional[pulumi.Input[builtins.int]] = None,
            vu_max_per_test: Optional[pulumi.Input[builtins.int]] = None,
            vuh_max_per_month: Optional[pulumi.Input[builtins.int]] = None) -> 'ProjectLimits':
        """
        Get an existing ProjectLimits resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] duration_max_per_test: Maximum duration of a test in seconds.
        :param pulumi.Input[builtins.str] project_id: The identifier of the project to manage limits for.
        :param pulumi.Input[builtins.int] vu_browser_max_per_test: Maximum number of concurrent browser virtual users (VUs) used in one test.
        :param pulumi.Input[builtins.int] vu_max_per_test: Maximum number of concurrent virtual users (VUs) used in one test.
        :param pulumi.Input[builtins.int] vuh_max_per_month: Maximum amount of virtual user hours (VU/h) used per one calendar month.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProjectLimitsState.__new__(_ProjectLimitsState)

        __props__.__dict__["duration_max_per_test"] = duration_max_per_test
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["vu_browser_max_per_test"] = vu_browser_max_per_test
        __props__.__dict__["vu_max_per_test"] = vu_max_per_test
        __props__.__dict__["vuh_max_per_month"] = vuh_max_per_month
        return ProjectLimits(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="durationMaxPerTest")
    def duration_max_per_test(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        Maximum duration of a test in seconds.
        """
        return pulumi.get(self, "duration_max_per_test")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[builtins.str]:
        """
        The identifier of the project to manage limits for.
        """
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter(name="vuBrowserMaxPerTest")
    def vu_browser_max_per_test(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        Maximum number of concurrent browser virtual users (VUs) used in one test.
        """
        return pulumi.get(self, "vu_browser_max_per_test")

    @property
    @pulumi.getter(name="vuMaxPerTest")
    def vu_max_per_test(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        Maximum number of concurrent virtual users (VUs) used in one test.
        """
        return pulumi.get(self, "vu_max_per_test")

    @property
    @pulumi.getter(name="vuhMaxPerMonth")
    def vuh_max_per_month(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        Maximum amount of virtual user hours (VU/h) used per one calendar month.
        """
        return pulumi.get(self, "vuh_max_per_month")

